==> openshift-model-machineconfig-5.12.3-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolSpecBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineConfigPoolSpecBuilder extends io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpec,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecBuilder>{
  public MachineConfigPoolSpecBuilder() {
    this(false);
  }
  public MachineConfigPoolSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineConfigPoolSpec(), validationEnabled);
  }
  public MachineConfigPoolSpecBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigPoolSpecBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineConfigPoolSpec(), validationEnabled);
  }
  public MachineConfigPoolSpecBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpec instance) {
    this(fluent, instance, false);
  }
  public MachineConfigPoolSpecBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfiguration(instance.getConfiguration()); 
    fluent.withMachineConfigSelector(instance.getMachineConfigSelector()); 
    fluent.withMaxUnavailable(instance.getMaxUnavailable()); 
    fluent.withNodeSelector(instance.getNodeSelector()); 
    fluent.withPaused(instance.getPaused()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigPoolSpecBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpec instance) {
    this(instance,false);
  }
  public MachineConfigPoolSpecBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfiguration(instance.getConfiguration()); 
    this.withMachineConfigSelector(instance.getMachineConfigSelector()); 
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withNodeSelector(instance.getNodeSelector()); 
    this.withPaused(instance.getPaused()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigPoolSpec build() {
    MachineConfigPoolSpec buildable = new MachineConfigPoolSpec(fluent.getConfiguration(),fluent.getMachineConfigSelector(),fluent.getMaxUnavailable(),fluent.getNodeSelector(),fluent.getPaused());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineConfigPoolSpecBuilder that = (MachineConfigPoolSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machineconfig-6.2.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolSpecBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineConfigPoolSpecBuilder extends MachineConfigPoolSpecFluentImpl<MachineConfigPoolSpecBuilder> implements VisitableBuilder<MachineConfigPoolSpec,MachineConfigPoolSpecBuilder>{
  public MachineConfigPoolSpecBuilder() {
    this(false);
  }
  public MachineConfigPoolSpecBuilder(Boolean validationEnabled) {
    this(new MachineConfigPoolSpec(), validationEnabled);
  }
  public MachineConfigPoolSpecBuilder(MachineConfigPoolSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigPoolSpecBuilder(MachineConfigPoolSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineConfigPoolSpec(), validationEnabled);
  }
  public MachineConfigPoolSpecBuilder(MachineConfigPoolSpecFluent<?> fluent,MachineConfigPoolSpec instance) {
    this(fluent, instance, false);
  }
  public MachineConfigPoolSpecBuilder(MachineConfigPoolSpecFluent<?> fluent,MachineConfigPoolSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfiguration(instance.getConfiguration()); 
    fluent.withMachineConfigSelector(instance.getMachineConfigSelector()); 
    fluent.withMaxUnavailable(instance.getMaxUnavailable()); 
    fluent.withNodeSelector(instance.getNodeSelector()); 
    fluent.withPaused(instance.getPaused()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigPoolSpecBuilder(MachineConfigPoolSpec instance) {
    this(instance,false);
  }
  public MachineConfigPoolSpecBuilder(MachineConfigPoolSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfiguration(instance.getConfiguration()); 
    this.withMachineConfigSelector(instance.getMachineConfigSelector()); 
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withNodeSelector(instance.getNodeSelector()); 
    this.withPaused(instance.getPaused()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineConfigPoolSpecFluent<?> fluent;
  Boolean validationEnabled;
  public MachineConfigPoolSpec build() {
    MachineConfigPoolSpec buildable = new MachineConfigPoolSpec(fluent.getConfiguration(),fluent.getMachineConfigSelector(),fluent.getMaxUnavailable(),fluent.getNodeSelector(),fluent.getPaused());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
